summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/imageviewer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/imageviewer.h')
-rw-r--r--kstars/kstars/imageviewer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/imageviewer.h b/kstars/kstars/imageviewer.h
index ed475f6c..7b092f26 100644
--- a/kstars/kstars/imageviewer.h
+++ b/kstars/kstars/imageviewer.h
@@ -37,7 +37,7 @@
*save these files. For other formats, like PNG, this is not so important
*because they can directly saved by TQImage.
*
*The download-slave works asynchron so the tqparent-widget can be used at
*this time. The save-slave works synchronously, but this is not important
*because the files are at this time local saved and this works not so long.
*/
@@ -51,7 +51,7 @@ class ImageViewer : public KMainWindow {
public:
/**Constructor. */
- ImageViewer (const KURL *imageName, const TQString &capText, TQWidget *tqparent, const char *name = 0);
+ ImageViewer (const KURL *imageName, const TQString &capText, TQWidget *parent, const char *name = 0);
/**Destructor. If there is a partially downloaded image file, delete it.*/
~ImageViewer();
@@ -37,7 +37,7 @@
*because they can directly saved by TQImage.
*
- *The download-slave works asynchron so the tqparent-widget can be used at
+ *The download-slave works asynchron so the parent-widget can be used at
*this time. The save-slave works synchronously, but this is not important
*because the files are at this time local saved and this works not so long.